=======
History
=======

1.0.2b1 (2019-10-25)
-------------------------

* Second release with package missing error fixes

1.0.1b2 (2019-09-23)
-------------------------

* Beta release 2

1.0.1b1 (2019-09-23)
-------------------------

* First beta release

0.4.5 (2019-09-23)
------------------

* Major CLI look and fell changes
* Bug fixes

0.4.4 (2019-09-20)
------------------

* Bug fixes as CISCO api changes

0.4.3 (2019-09-19)
------------------

* IOS device reset functionality added
* Listing of all available sites
* Sample data modifications
* Bug fixes
* New api references added
* Bulk site creation

0.4.2 (2019-08-30)
------------------

* Fixed skipped serial number bug
* Removed pagination dependency

0.4.1 (2019-08-29)
------------------

* Documentation updates

0.3.5 (2019-08-29)
------------------

* Fixed template version mismatch
* Added csv export functionality

0.3.4 (2019-08-26)
------------------

* Documentation updates

0.3.3 (2019-08-26)
------------------

* Separated token generator
* Modulated template functionality

0.3.2 (2019-08-24)
------------------

* Fixed bug for auto build
* Tokenize dependency for setup
* Removed .gz artifact storage
* Added usage instructions
* Updated documentation tutorials
* Added delete option for pnp devices
* Changed package dependency and encoding
* Fixed PnP flag for delete commands
* Updated delete instructions
* Introduced aliased group
* Added template handler
* Added template validation

0.3.1 (2019-08-20)
------------------

* Fixed documentation bugs for note and warning

0.2.5 (2019-08-19)
------------------

* Added api documentation
* Introduced first draft of documentation

0.2.4 (2019-08-19)
------------------

* Adding Jenkinsfile for auto build
* Adding jfrog-spec.json for artifact management

0.2.3 (2019-08-14)
------------------

* Updated issue #13
* Ready for testing

0.2.2 (2019-08-13)
------------------

* Fixed device delete bug (Issue #15)
* Updated Readme

0.2.1 (2019-08-08)
------------------

* Added CSV file read and json conversion
* Added input validation for bulk import
* Fixed Host not found BUG
* Added extra info to screen messages

0.1.5 (2019-08-07)
------------------

* Decoupled authentication process

0.1.4 (2019-08-07)
------------------

* Fixed version upgrade bug
* Removed device type in configurations

0.1.3 (2019-08-06)
------------------

* Added bulk import feature

0.1.2 (2019-08-06)
------------------

* Updated logging
* Updated syntax in source code
* Added API calls for importing devices
* Bug fix - Import devices
* Added device type in configurations
* Changed all log level default to DEBUG
* Added device claim
* Fixed issues

0.1.1 (2019-08-02)
------------------

* Added nested cli commands
* Added import handlers
* Added context management

0.1.0 (2019-07-31)
------------------

* Added functionality to login to DNAC
* Read configurations from file
* Default config locations for looking for configurations

0.1.0 (2019-07-30)
------------------

* First release on GitLab.
* Adding LICENSE
* Creating setup and structure
